$(document).ready(function () {
    $("table,th,td").css ({
        "border" : "2px solid black",
        "border-collapse" : "collapse",
        "padding" : "10px",
        "width"   : "16%"
    });

    $("thead").css("background-color", "#ddf");
    $("td").css ("text-align", "center");

    /* Chama a função calcular_total() quando o
     * botão #btn for pressionado
     */
    $("#btn").on ("click", calcular_total);
});

function isNumber(num)
{
    var re_tipo = /^\d+(\.\d+)?$/;
    return re_tipo.test(num);
}

function calcular_total () {
    //Selecionar as linhas que são filhas de tbody
    var linhas = ""

    //Obter o último "td" de cada linha

    $("#total").val(total);
}
