body {
    background-color : #003366;
    color : #fff;
    font-size : 16px;
    font-family : "Segoe UI", Helvetica, Tahoma;
}

input.nome {
    position: relative;
    left: 10px;
}

input.senha {
    position: relative;
    left: 6px;
}

input.btn {
    position:relative;
    left:62px;
}